@@ -26,6 +26,7 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityMovingStandardDeviation
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingCountedPositive
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingPositiveAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingRSI
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingCorrelation
 from PyFin.Analysis.TechnicalAnalysis import SecuritySignValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityXAverageValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityMACDValueHolder
@@ -59,6 +60,7 @@ from PyFin.Analysis.CrossSectionValueHolders import CSBottomNPercentileSecurityV
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageAdjustedSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSZScoreSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSFillNASecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSPercentileSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSResidueSecurityValueHolder
 
@@ -99,6 +101,10 @@ def CSZScore(x, groups=None):
     return CSZScoreSecurityValueHolder(x, groups)
 
 
+def CSFillNA(x, groups=None):
+    return CSFillNASecurityValueHolder(x, groups)
+
+
 def CSRes(left, right):
     return CSResidueSecurityValueHolder(left, right)
 
@@ -119,6 +125,10 @@ def RSI(window, x='x'):
     return SecurityMovingRSI(window, x)
 
 
+def MCORR(window, x='x', y='y'):
+    return SecurityMovingCorrelation(window, x, y)
+
+
 def MA(window, x='x'):
     return SecurityMovingAverage(window, x)
 
@@ -260,11 +270,11 @@ def ROUND(x):
 
 
 def SHIFT(x, n):
-    return SecurityShiftedValueHolder(x, n)
+    return SecurityShiftedValueHolder(n, x)
 
 
 def DELTA(x, n):
-    return SecurityDeltaValueHolder(x, n)
+    return SecurityDeltaValueHolder(n, x)
 
 
 def IIF(flag, left, right):
